# -*- coding: utf-8 -*- 
import numpy as np
import pandas as pd
import matplotlib.pylab as plt
import matplotlib
from mpl_finance import candlestick_ohlc
from matplotlib.dates import date2num

matplotlib.rcParams['font.family'] ='Yu Mincho' # matplotlibで日本語を使う

df0 = pd.read_csv('N225.csv', index_col='Date', parse_dates=[0])
df = df0[df0['Open'].notnull()] # Nullのある行を削除
df = df.sort_index() #ソートにより，期間指定抽出がしやすくなる
df1 = df.loc['20170901':'20170930', ['Open','High','Low','Close']] #2017年9月，1か月だけを見る

df1['Close'].plot(label='9月の終値') #終値のプロット
plt.legend(loc='upper left')

fig, ax = plt.subplots()

xdate = [x.date() for x in df1.index] #Timestamp -> datetime
ohlc = np.vstack((date2num(xdate), df1.values.T)).T #datetime -> float
candlestick_ohlc(ax, ohlc, width=0.7, colorup='g', colordown='r')

plt.title('9月のローソク足')
ax.grid() #グリッド表示
ax.set_xlim(df1.index[0].date(), df1.index[-1].date()) #x軸の範囲
fig.autofmt_xdate() #x軸のオートフォーマット
plt.show()
