# -*- coding: utf-8 -*-
# 次を参照 
# http://docs.opencv.org/3.0-beta/doc/py_tutorials/py_objdetect/py_face_detection/py_face_detection.html#face-detection
# https://qiita.com/hitomatagi/items/04b1b26c1bc2e8081427
import cv2
import numpy as np

# Haar-like 特徴分類器の読み込み
face_cascade = cv2.CascadeClassifier('haarcascades/haarcascade_frontalface_default.xml')
eye_cascade = cv2.CascadeClassifier('haarcascades/haarcascade_eye.xml')

img = cv2.imread('Lenna.tiff')
gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)

faces = face_cascade.detectMultiScale(gray) # 顔検出
for (x,y,w,h) in faces:
    cv2.rectangle(img,(x,y),(x+w,y+h),(255,0,0),2) # 検出した顔を矩形で囲む
    roi_gray = gray[y:y+h, x:x+w] # 顔領域（グレースケール）
    roi_color = img[y:y+h, x:x+w] # 顔領域（カラー）
    eyes = eye_cascade.detectMultiScale(roi_gray) # 顔の中から眼を検出
    for (ex,ey,ew,eh) in eyes:
        cv2.rectangle(roi_color,(ex,ey),(ex+ew,ey+eh),(0,255,0),2) # 検出した眼を矩形で囲む
cv2.imshow('img',img)
cv2.waitKey(0)
cv2.destroyAllWindows()